==> estateplat-common-1.2.4-20220613.122018-1041-sources.jar: cn/gtmap/estateplat/model/server/core/BdcScSh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/6/10
 * @description 不动产删除审核
 */
@Table(name = "BDC_SCSH")
public class BdcScSh {
    /**
     * 审核id
     */
    @Id
    private String shid;
    /**
     * 受理编号
     */
    private String slbh;
    /**
     * 删除申请时间
     */
    private Date sqscsj;
    /**
     * 权利人名称
     */
    private String qlrmc;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 删除原因
     */
    private String scyy;
    /**
     * 审核意见
     */
    private String shyj;
    /**
     * 审核人
     */
    private String shr;

    public String getShid() {
        return shid;
    }

    public void setShid(String shid) {
        this.shid = shid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public Date getSqscsj() {
        return sqscsj;
    }

    public void setSqscsj(Date sqscsj) {
        this.sqscsj = sqscsj;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getScyy() {
        return scyy;
    }

    public void setScyy(String scyy) {
        this.scyy = scyy;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }
}

==> estateplat-common-1.2.4-20230610.023630-1177-sources.jar: cn/gtmap/estateplat/model/server/core/BdcScSh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/6/10
 * @description 不动产删除审核
 */
@Table(name = "BDC_SCSH")
public class BdcScSh {
    /**
     * 审核id
     */
    @Id
    private String shid;
    /**
     * wiid
     */
    private String wiid;
    /**
     * 受理编号
     */
    private String slbh;
    /**
     * 删除申请时间
     */
    private Date sqscsj;
    /**
     * 权利人名称
     */
    private String qlrmc;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 删除原因
     */
    private String scyy;
    /**
     * 审核意见
     */
    private String shyj;
    /**
     * 审核人
     */
    private String shr;
    /**
     * 审核状态
     */
    private String shzt;

    public String getShid() {
        return shid;
    }

    public void setShid(String shid) {
        this.shid = shid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public Date getSqscsj() {
        return sqscsj;
    }

    public void setSqscsj(Date sqscsj) {
        this.sqscsj = sqscsj;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getScyy() {
        return scyy;
    }

    public void setScyy(String scyy) {
        this.scyy = scyy;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }
}
